| Title: | p-Value Aggregation Methods |
|---|---|
| Description: | Contains functionality for performing the following methods of p-value aggregation: Fisher's method [Fisher, RA (1932, ISBN: 9780028447308)], the Lancaster method (weighted Fisher's method) [Lancaster, HO (1961, <doi:10.1111/j.1467-842X.1961.tb00058.x>)], and Sidak correction [Sidak, Z (1967, <doi:10.1080/01621459.1967.10482935>)]. Please cite Yi et al., the manuscript corresponding to this package [Yi, L et al., (2017), <doi:10.1101/190199>]. |
| Authors: | Lynn Yi [aut], Lior Pachter [aut], Elise Maigne [cre] |
| Maintainer: | Elise Maigne <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.2 |
| Built: | 2026-06-06 07:15:19 UTC |
| Source: | https://github.com/cran/aggregation |
Aggregate p-values with equal weights. Equivalent to the Lancaster method with all p-values weighted at 2.
fisher(pvalues)fisher(pvalues)
pvalues |
A vector of p-values (i.e. between 0 and 1) to be aggregated with Fisher's method. NAs will be filtered out. |
fisher(c(.1, .2, .3))fisher(c(.1, .2, .3))
Weighted p-value aggregation.
lancaster(pvalues, weights)lancaster(pvalues, weights)
pvalues |
A vector of p-values (i.e. between 0 and 1). NAs will be filtered out. |
weights |
A vector of weights, each associated with its respective p-value. Weights must be nonegative. NAs and negative weights will be filtered out with corresponding p-values. |
lancaster(c(.1, .5), c(2, 4))lancaster(c(.1, .5), c(2, 4))
The Sidak method uses the minimum p-value but corrects it for the number of p-values that are aggregated.
sidak(pvalues)sidak(pvalues)
pvalues |
A vector of p-values to be aggregated. NAs will be filtered. |
sidak(c(.1, .2, .3))sidak(c(.1, .2, .3))