| Type: | Package |
| Title: | p-Value Aggregation Methods |
| Version: | 1.0.2 |
| Date: | 2026-06-05 |
| Description: | Contains functionality for performing the following methods of p-value aggregation: Fisher's method [Fisher, RA (1932, ISBN: 9780028447308)], the Lancaster method (weighted Fisher's method) [Lancaster, HO (1961, <doi:10.1111/j.1467-842X.1961.tb00058.x>)], and Sidak correction [Sidak, Z (1967, <doi:10.1080/01621459.1967.10482935>)]. Please cite Yi et al., the manuscript corresponding to this package [Yi, L et al., (2017), <doi:10.1101/190199>]. |
| License: | GPL-3 |
| NeedsCompilation: | no |
| Packaged: | 2026-06-05 07:59:03 UTC; emaigne |
| Repository: | CRAN |
| Config/roxygen2/version: | 8.0.0 |
| Encoding: | UTF-8 |
| Imports: | stats |
| Author: | Lynn Yi [aut], Lior Pachter [aut], Elise Maigne [cre] |
| Maintainer: | Elise Maigne <elise.maigne@inrae.fr> |
| Date/Publication: | 2026-06-05 09:10:02 UTC |
Fisher's Method
Description
Aggregate p-values with equal weights. Equivalent to the Lancaster method with all p-values weighted at 2.
Usage
fisher(pvalues)
Arguments
pvalues |
A vector of p-values (i.e. between 0 and 1) to be aggregated with Fisher's method. NAs will be filtered out. |
Examples
fisher(c(.1, .2, .3))
Lancaster method
Description
Weighted p-value aggregation.
Usage
lancaster(pvalues, weights)
Arguments
pvalues |
A vector of p-values (i.e. between 0 and 1). NAs will be filtered out. |
weights |
A vector of weights, each associated with its respective p-value. Weights must be nonegative. NAs and negative weights will be filtered out with corresponding p-values. |
Examples
lancaster(c(.1, .5), c(2, 4))
Perform the Sidak method.
Description
The Sidak method uses the minimum p-value but corrects it for the number of p-values that are aggregated.
Usage
sidak(pvalues)
Arguments
pvalues |
A vector of p-values to be aggregated. NAs will be filtered. |
Examples
sidak(c(.1, .2, .3))